# API Reference

This section contains the auto-generated API documentation from the kanoa source code.

```{eval-rst}
.. automodule:: kanoa
   :members:
   :undoc-members:
   :show-inheritance:
```

## Core

```{eval-rst}
.. automodule:: kanoa.core.interpreter
   :members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: kanoa.core.types
   :members:
   :undoc-members:
   :show-inheritance:
```

## Backends

```{eval-rst}
.. automodule:: kanoa.backends.gemini
   :members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: kanoa.backends.claude
   :members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: kanoa.backends.molmo
   :members:
   :undoc-members:
   :show-inheritance:
```

## Knowledge Base

```{eval-rst}
.. automodule:: kanoa.knowledge_base.text_kb
   :members:
   :undoc-members:
   :show-inheritance:
```

```{eval-rst}
.. automodule:: kanoa.knowledge_base.pdf_kb
   :members:
   :undoc-members:
   :show-inheritance:
```
